package test.a1;

import javax.microedition.khronos.egl.EGL10;
import javax.microedition.khronos.egl.EGLConfig;
import javax.microedition.khronos.egl.EGLDisplay;
import javax.microedition.khronos.opengles.GL10;

import android.app.Activity;
import android.opengl.GLSurfaceView;
import android.os.Bundle;

import com.threed.jpct.Camera;
import com.threed.jpct.Config;
import com.threed.jpct.FrameBuffer;
import com.threed.jpct.World;

/**
 * 
 * @author  hakan eryargi (r a f t)
 */
public class PoseTestActivity extends Activity {

	private GLSurfaceView mGLView;
	private MyRenderer renderer = null;
	private World world = null;
	
	private AnimatedObject object = new AnimatedObject();
	
	private boolean paused = false;
	
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		mGLView = new GLSurfaceView(getApplication());

		mGLView.setEGLConfigChooser(new GLSurfaceView.EGLConfigChooser() {
			public EGLConfig chooseConfig(EGL10 egl, EGLDisplay display) {
				// Ensure that we get a 16bit framebuffer. Otherwise, we'll fall
				// back to Pixelflinger on some device (read: Samsung I7500)
				int[] attributes = new int[] { EGL10.EGL_DEPTH_SIZE, 16, EGL10.EGL_NONE };
				EGLConfig[] configs = new EGLConfig[1];
				int[] result = new int[1];
				egl.eglChooseConfig(display, attributes, configs, 1, result);
				return configs[0];
			}
		});
		renderer = new MyRenderer();
		mGLView.setRenderer(renderer);
		setContentView(mGLView);
	}

	@Override
	protected void onPause() {
		paused = true;
		super.onPause();
		mGLView.onPause();
	}

	@Override
	protected void onResume() {
		paused = false;
		super.onResume();
		mGLView.onResume();
	}

	protected void onStop() {
		super.onStop();
		renderer.stop();
	}

	protected boolean isFullscreenOpaque() {
		return true;
	}

	class MyRenderer implements GLSurfaceView.Renderer {

		private FrameBuffer frameBuffer = null;

		private boolean stop = false;

		public MyRenderer() {
			Config.maxPolysVisible = 5000;
			Config.farPlane = 1500;
		}

		public void stop() {
			stop = true;
			if (frameBuffer != null) {
				frameBuffer.dispose();
				frameBuffer = null;
			}
		}

		public void onSurfaceChanged(GL10 gl, int w, int h) {
			if (frameBuffer != null) {
				frameBuffer.dispose();
			}
			frameBuffer = new FrameBuffer(gl, w, h);
		}

		public void onSurfaceCreated(GL10 gl, EGLConfig config) {
			world = new World();

			object.build();
			world.addObject(object);
			world.setAmbientLight(255, 255, 255);
			
			world.getCamera().moveCamera(Camera.CAMERA_MOVEOUT, 8f);
		}

		public void onDrawFrame(GL10 gl) {

			if (!stop) {

				if (paused) {
					try {
						Thread.sleep(500);
					} catch (InterruptedException e) {
					}
				} else {
					float seconds = 0.1f;
					object.animatePose(seconds);
					
					frameBuffer.clear();
					world.renderScene(frameBuffer);
					world.draw(frameBuffer);
					frameBuffer.display();
				}
			} else {
				if (frameBuffer != null) {
					frameBuffer.dispose();
					frameBuffer = null;
				}
				try {
					// Note to self: Why am i doing this...?
					Thread.sleep(100);
				} catch (InterruptedException e) {
				}
			}
		}

	}
}
	


